@@ -29,11 +29,9 @@ sub connect
 {
     my $self = shift;
 
-    return if $self->{dbh} && $self->{dbh}->ping;
-
     $self->disconnect if $self->{dbh};
     $self->{dbh} = $self->_make_dbh( @_,
-                                     name => $self->{schema}->name
+                                     name => $self->{schema}->db_schema_name
                                    );
 
     foreach ( $self->rows( sql => 'SHOW VARIABLES' ) )
@@ -98,7 +96,7 @@ sub rdbms_version
 {
     my $self = shift;
 
-    $self->_check_dbh;
+    $self->_ensure_valid_dbh;
     my $version = $self->{dbh}{mysql_serverinfo};
 
     $version =~ s/[^\d\.]//g;
@@ -127,7 +125,7 @@ sub create_database
 {
     my $self = shift;
 
-    my $db = $self->{schema}->name;
+    my $db = $self->{schema}->db_schema_name;
 
     my $dbh = $self->_make_dbh( name => '',
                                 @_ );
@@ -143,7 +141,7 @@ sub drop_database
 {
     my $self = shift;
 
-    my $db = $self->{schema}->name;
+    my $db = $self->{schema}->db_schema_name;
 
     my $dbh = $self->_make_dbh( name => '',
                                 @_ );
@@ -155,7 +153,7 @@ sub drop_database
     $dbh->disconnect;
 }
 
-sub _make_dbh
+sub _connect_params
 {
     my $self = shift;
 
@@ -177,28 +175,17 @@ sub _make_dbh
     $dsn .= ";host=$p{host}" if $p{host};
     $dsn .= ";port=$p{port}" if $p{port};
 
-    foreach my $k ( grep { /^mysql/ } keys %p )
+    foreach my $k ( grep { /^mysql_/ } keys %p )
     {
         $dsn .= ";$k=$p{$k}";
     }
 
-    my $dbh;
-    eval
-    {
-        $dbh = DBI->connect( $dsn,
-                             $p{user},
-                             $p{password},
-                             { RaiseError => 1,
-                               AutoCommit => 1,
-                               PrintError => 0,
-                             }
-                           );
-    };
-
-    Alzabo::Exception::Driver->throw( error => $@ ) if $@;
-    Alzabo::Exception::Driver->throw( error => "Unable to connect to database\n" ) unless $dbh;
-
-    return $dbh;
+    return [ $dsn, $p{user}, $p{password},
+             { RaiseError => 1,
+               AutoCommit => 1,
+               PrintError => 0,
+             }
+           ];
 }
 
 sub next_sequence_number
